@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2014-2021 Canonical, Ltd.
+ * Copyright (C) 2021-2023 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * Author: Colin Ian King <colin.king@canonical.com>
+ * Author: Colin Ian King <colin.i.king@gmail.com>
  */
 #define _GNU_SOURCE
 #define _XOPEN_SOURCE_EXTENDED
@@ -507,7 +508,7 @@ static inline unsigned int OPTIMIZE3 HOT count_bits(const unsigned int val)
 
 /*
  *  procnamecmp()
- *	compare process names upto the end of string or ' '
+ *	compare process names up to the end of string or ' '
  */
 static int procnamecmp(const char *s1, const char *s2)
 {
@@ -945,7 +946,7 @@ static void fault_cache_cleanup(void)
  */
 static const char *get_proc_self_stat_field(const char *buf, const int num)
 {
-	const char *ptr = buf, *comm_end;
+	const char *ptr, *comm_end;
 	int n;
 
 	if (num < 1 || !buf || !*buf)
